@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #ifndef ULOZ_H
 #define ULOZ_H
 
@@ -22,7 +39,7 @@ public:
     inline bool loginSupported() const { return true; }
     void login(const QString &username, const QString &password);
     inline bool recaptchaRequired() const { return true; }
-    inline QString recaptchaKey() const { return m_captchaId; }
+    inline QString recaptchaKey() const { return m_captchaKey; }
     inline QString recaptchaServiceName() const { return QString("Uloz"); }
     inline int maximumConnections() const { return m_connections; }
     bool cancelCurrentOperation();
@@ -41,8 +58,8 @@ signals:
 
 private:
     QUrl m_url;
-    QString m_captchaId;
     QString m_captchaKey;
+    QString m_token;
     QString m_timestamp;
     QString m_cid;
     QString m_sign;
