@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #include "youtube.h"
 #include "json.h"
 #include <QNetworkAccessManager>
@@ -21,11 +38,15 @@ using namespace QtJson;
 YouTube::YouTube(QObject *parent) :
     ServicePlugin(parent)
 {
-    m_formatList << 37 << 22 << 35 << 34 << 18;
+    m_formatList << 37 << 22 << 35 << 34 << 18 << 36 << 17;
+
+    if (!decryptionEngine) {
+	decryptionEngine = new QScriptEngine;
+    }
 }
 
 QRegExp YouTube::urlPattern() const {
-    return QRegExp("(http://(www.|m.|)youtube.com/(v/|.+)(v=|list=|)|http://youtu.be/)", Qt::CaseInsensitive);
+    return QRegExp("(http(s|)://(www.|m.|)youtube.com/(v/|.+)(v=|list=|)|http://youtu.be/)", Qt::CaseInsensitive);
 }
 
 bool YouTube::urlSupported(const QUrl &url) const {
@@ -134,7 +155,7 @@ void YouTube::getDownloadRequest(const QUrl &webUrl) {
 }
 
 void YouTube::getYouTubeVideoInfoPage(const QString &id) {
-    QUrl url("http://www.youtube.com/get_video_info");
+    QUrl url("https://www.youtube.com/get_video_info");
 #if QT_VERSION >= 0x050000
     QUrlQuery query;
     query.addQueryItem("video_id", id);
@@ -187,7 +208,7 @@ void YouTube::checkYouTubeVideoInfoPage() {
 #endif
         }
         else {
-            response.replace(QRegExp("%2C(\\w+%3D1%26|)" + separator), "," + separator);
+            response = response.section("&", 0, 0).replace("%2C", ",");
             this->parseYouTubeVideoPage(QScriptValue(), response);
         }
     }
@@ -314,8 +335,10 @@ void YouTube::addYouTubeDecryptionFunctionToCache() {
 
     QString response(reply->readAll());
     QString funcName = response.section("signature=", 1, 1).section('(', 0, 0);
-    response = QString("function %1%2").arg(funcName).arg(response.section("function " + funcName, 1, 1).section(";function", 0, 0));
-    decryptionEngine->evaluate(response);
+    QString var = response.section("function " + funcName, 0, 0).section(";var", -1);
+    QString funcBody = QString("function %2%3").arg(funcName).arg(response.section("function " + funcName, 1, 1).section(";function", 0, 0));
+    QString js = QString("var%1 %2").arg(var).arg(funcBody);
+    decryptionEngine->evaluate(js);
 
     QScriptValue global = decryptionEngine->globalObject();
     QScriptValue decryptionFunction = global.property(funcName);
