@@ -37,7 +37,7 @@ int qdl_read(struct qdl_device *qdl, void *buf, size_t len,
 int qdl_write(struct qdl_device *qdl, const void *buf, size_t len, bool eot);
 
 int firehose_run(struct qdl_device *qdl, const char *incdir,
-                 const char *storage);
+                 const char *storage, void *progress_callback_context);
 int sahara_run(struct qdl_device *qdl, char *prog_mbn);
 void print_hex_dump(const char *prefix, const void *buf, size_t len);
 unsigned attr_as_unsigned(xmlNode *node, const char *attr, int *errors);
